@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains code for fishing the data out of <book>, <bookinfo>, or
 <article> elements. */
@@ -153,10 +154,9 @@ static uschar *
 extract_string(item *i)
 {
 int length = 0;
-item *ii;
 uschar *yield, *s;
 
-for (ii = i->next; ii != i->partner; ii = ii->next)
+for (item *ii = i->next; ii != i->partner; ii = ii->next)
   {
   if (Ustrcmp(ii->name, "#PCDATA") != 0) continue;
   length += ii->p.txtblk->length;
@@ -164,7 +164,7 @@ for (ii = i->next; ii != i->partner; ii = ii->next)
 
 s = yield = misc_malloc(length + 1);
 
-for (ii = i->next; ii != i->partner; ii = ii->next)
+for (item *ii = i->next; ii != i->partner; ii = ii->next)
   {
   if (Ustrcmp(ii->name, "#PCDATA") != 0) continue;
   memcpy(s, ii->p.txtblk->string, ii->p.txtblk->length);
@@ -177,6 +177,7 @@ return yield;
 }
 
 
+
 /*************************************************
 *         Extract a sub-itemlist                 *
 *************************************************/
@@ -225,13 +226,10 @@ Returns:     nothing
 static void
 extract_bookinfo_elements(item *i, bookinfo_element *bi_list)
 {
-item *ii;
-bookinfo_element *bi;
-
-for (ii = i->next; ii != i->partner; ii = ii->next)
+for (item *ii = i->next; ii != i->partner; ii = ii->next)
   {
   if (ii->partner == ii) continue;
-  for (bi = bi_list; bi->name != NULL; bi++)
+  for (bookinfo_element *bi = bi_list; bi->name != NULL; bi++)
     {
     if (Ustrcmp(ii->name, bi->name) == 0)
       {
