@@ -2,9 +2,10 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2005, last modified March 2023 */
 
-/* This module contains fixed data in the form of various tables */
+/* This module contains fixed data in the form of various tables. */
 
 
 #include "sdop.h"
@@ -16,7 +17,7 @@
 *************************************************/
 
 /* The "revisionflag" attribute is supported on all elements. The "toc"
-attribute for tables is not DocBook; is use used internally by SDoP for the
+attribute for tables is not DocBook; it is use used internally by SDoP for the
 table that forms the TOC. Some attributes are recognized, but not used in the
 formatting. The nocheck_attrs list is used for elements that are completely
 ignored. */
@@ -210,7 +211,7 @@ The entities that are commented out are some that are listed in the DocBook
 specification, but which do not correspond to characters in the PostScript
 fonts. Some of those that are not commented out (e.g. Cdot) are recognized by
 SDoP because their codes are less than 017F, but as they don't have glyphs in
-the PostScript fonts, they are printed as the currency symbol. */
+the PostScript fonts, they are output as the currency symbol. */
 
 entity_block entity_list[] = {
   { US"AElig",             US"&#x00c6" },
@@ -1027,6 +1028,7 @@ an2uencod an2ulist[] = {
   { US"Lslash",          0x0141, -1 },
   { US"M",               0x004d, -1 },
   { US"N",               0x004e, -1 },
+  { US"NBspace",         0x00a0, -1 },
   { US"Nacute",          0x0143, -1 },
   { US"Ncaron",          0x0147, -1 },
   { US"Ncommaaccent",    0x0145, -1 },
