@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains debugging functions. */
 
@@ -13,7 +14,7 @@
 *             Debug printing function            *
 *************************************************/
 
-/* Pretty obvious really. Look just like printf(), but prints to stderr.
+/* Pretty obvious really. Looks just like printf(), but outputs to stderr.
 
 Arguments:
   format        a format string
@@ -34,6 +35,7 @@ va_end(ap);
 }
 
 
+
 /*************************************************
 *              Print a string                    *
 *************************************************/
@@ -62,6 +64,7 @@ debug_printf("%s", post);
 }
 
 
+
 /*************************************************
 *            Print a fixed-point number          *
 *************************************************/
@@ -135,6 +138,7 @@ debug_printf("\n");
 }
 
 
+
 /*************************************************
 *            Print a paragraph                   *
 *************************************************/
@@ -214,10 +218,9 @@ Returns:     nothing
 void
 debug_print_item_list(item *item_list, const char *when)
 {
-item *i;
 if (internal_processing && (debug_selector & D_internal) == 0) return;
 debug_printf("----- Item list %s -----\n", when);
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
   if (i->next != NULL && i->next->prev != i)
     {
@@ -367,13 +370,12 @@ Returns:     nothing
 void
 debug_print_para(item *item_list, item *last_item, const char *when)
 {
-item *i;
 int pagenumber = 0;
 BOOL pending_page = FALSE;
 
 if (internal_processing && (debug_selector & D_internal) == 0) return;
 debug_printf("----- Paragraphs %s -----\n", when);
-for (i = item_list; i != NULL && i != last_item; i = i->next)
+for (item *i = item_list; i != NULL && i != last_item; i = i->next)
   {
   if (Ustrcmp(i->name, "#PCPARA") == 0)
     {
