@@ -2,9 +2,10 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: April 2023 */
 
-/* Error handling routines */
+/* Error handling functions */
 
 #include "sdop.h"
 
@@ -31,7 +32,6 @@ typedef struct {
 
 
 static error_struct error_data[] = {
-
 /* 0-4 */
 { ec_disaster, "failed to open %s (%s): %s" },
 { ec_disaster, "malloc failed: requested %d bytes" },
@@ -168,7 +168,7 @@ static error_struct error_data[] = {
 { ec_serious,  "subscript_down or superscript_up value is too large" },
 { ec_serious,  "\"yes\" or \"no\" expected but \"%s\" found" },
 { ec_warning,  "page_full_length=%s is too small; set to 108" },
-{ ec_disaster, "error while processing PNG file: %s" },
+{ ec_disaster, "error while processing %s file: %s" },
 /* 110 - 114 */
 { ec_disaster, "internal error: missing <xref> while generating output" },
 { ec_disaster, "internal error: unset reference to %s while generating output" },
@@ -179,10 +179,12 @@ static error_struct error_data[] = {
 { ec_disaster, "too many nested lists" },
 /* 115 - 119 */
 { ec_noerror,  "'%s' is deprecated: use '%s' instead" },
-{ ec_disaster, "internal error: font for %s list has not been set up" }
+{ ec_disaster, "internal error: font for %s list has not been set up" },
+{ ec_disaster, "internal error: call to atexit() failed" },
+{ ec_disaster, "internal error: freeing block not on the list" }
 };
 
-#define error_maxerror 116
+#define ERROR_MAXERROR (int)(sizeof(error_data)/sizeof(error_struct))
 
 
 
@@ -190,8 +192,8 @@ static error_struct error_data[] = {
 *              Error message generator           *
 *************************************************/
 
-/* This function output an error or warning message, and may abandon the
-process if the error is sufficiently serious, or if there have been too many
+/* This function outputs an error or warning message, and may abandon the
+program if the error is sufficiently serious, or if there have been too many
 less serious errors. If there are too many warnings, subsequent ones are
 suppressed.
 
@@ -210,7 +212,7 @@ int ec;
 va_list ap;
 va_start(ap, n);
 
-if (n > error_maxerror)
+if (n > ERROR_MAXERROR)
   {
   (void)fprintf(stderr, "** Unknown error number %d\n", n);
   ec = ec_disaster;
