@@ -2,8 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
-/* Last modified August 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains functions related to fonts. */
 
@@ -11,7 +11,6 @@
 
 
 
-
 /*************************************************
 *             Find a bullet value                *
 *************************************************/
@@ -38,10 +37,7 @@ else if (Ustrcmp(markname, "dash") == 0) return BULLET_DASH;
 else if (Ustrcmp(markname, "opencircle") == 0) return BULLET_OCIRCLE;
 else if (markname[0] == 'U' && markname[1] == '+')
   {
-    /* Making this uschar instead of char causes gcc to mutter
-    "dereferencing type-punned pointer will break strict-aliasing rules"
-    and there seems to other way to stop it. */
-  char *endptr;
+  uschar *endptr;
   unsigned int ucode = Ustrtoul(markname + 1, &endptr, 16);
   if (*endptr != 0) error(66, markname); else return ucode;
   }
@@ -92,14 +88,16 @@ return -1;
 *        Kern table sorting comparison           *
 *************************************************/
 
-/* This is the auxiliary routine used for comparing kern
-table entries when sorting them. */
+/* This is the auxiliary function used for comparing kern table entries when
+sorting them. The pair values are all unsigned but subtracting them may produce
+a negative number, hence the fiddling about with casts below. */
 
-static int table_cmp(const void *a, const void *b)
+static int
+table_cmp(const void *a, const void *b)
 {
 kerntablestr *ka = (kerntablestr *)a;
 kerntablestr *kb = (kerntablestr *)b;
-return ka->pair - kb->pair;
+return (int)((int64_t)(ka->pair) - (int64_t)(kb->pair));
 }
 
 
@@ -108,7 +106,8 @@ return ka->pair - kb->pair;
 *          Number reader from AFM files          *
 *************************************************/
 
-static uschar *read_number(int *value, uschar *p)
+static uschar *
+read_number(int *value, uschar *p)
 {
 int n = 0;
 int sign = 1;
@@ -141,7 +140,6 @@ font_loadtables(afontstr *af)
 {
 FILE *f;
 kerntablestr *kerntable;
-int i;
 int kerncount = 0;
 int finalcount = 0;
 int *widths;
@@ -169,7 +167,7 @@ DEBUG(D_fontload) debug_printf("Loading metrics for %s from %s\n",
   af->name, filename);
 
 widths = af->widths = misc_malloc(LOWCHARLIMIT * sizeof(int));
-for (i = 0; i < LOWCHARLIMIT; i++) widths[i] = WIDTH_UNKNOWN;
+for (int i = 0; i < LOWCHARLIMIT; i++) widths[i] = WIDTH_UNKNOWN;
 af->kerncount = 0;
 
 /* Process the AFM file. First find the start of the metrics; on the way, check
@@ -276,7 +274,7 @@ amount). */
 pp = line + 14;
 while (*pp != 0 && *pp == ' ') pp++;
 (void)read_number(&kerncount, pp);
-af->kerns = kerntable = malloc(kerncount*sizeof(kerntablestr));
+af->kerns = kerntable = misc_malloc(kerncount*sizeof(kerntablestr));
 
 finalcount = 0;
 while (kerncount--)
@@ -342,14 +340,12 @@ DEBUG(D_fontload) debug_printf("Loaded\n");
 #ifdef NEVER
 debug_printf("FONT %s\n", af->name);
   {
-  int i;
-
-  for (i = 0; i < LOWCHARLIMIT; i++)
+  for (int i = 0; i < LOWCHARLIMIT; i++)
     {
     debug_printf("%04x %5d\n", i, af->widths[i]);
     }
 
-  for (i = LOWCHARLIMIT; i < 0xffff; i++)
+  for (int i = LOWCHARLIMIT; i < 0xffff; i++)
     {
     tree_node *t;
     uschar key[4];
@@ -362,7 +358,7 @@ debug_printf("FONT %s\n", af->name);
     }
 
   debug_printf("KERNS %d\n", af->kerncount);
-  for (i = 0; i < af->kerncount; i++)
+  for (int i = 0; i < af->kerncount; i++)
     {
     kerntablestr *k = &(af->kerns[i]);
     int a = (k->pair >> 16) & 0xffff;
@@ -433,15 +429,15 @@ if (c == ZERO_SPACE ||
      (af->stdencoding && (c == BREAK_PERMIT || c == NO_BREAK_HERE)))
   return 0;
 
-/* The "hard space" character, U+00A0, does not appear in the AFM files for the
-standard fonts. It is printed as a space, of course. */
+/* The "hard space" character, U+00A0, does not appear in the AFM files for
+some standard fonts. It is output as a space, of course. */
 
 if (c == HARD_SPACE && af->stdencoding) c = ' ';
 
 /* The most common, low-numbered characters, have their widths in a table.
 Unknown characters have a characteristic (unreasonable) width. We do not use a
-negative value, because there are fonts that contain characters with negative
-widths. */
+negative value, because there may be fonts that contain characters with
+negative widths. */
 
 if (c < LOWCHARLIMIT)
   {
@@ -556,6 +552,7 @@ return MUL(vf->sfont[which]->afont->widths[u2s->scode], vf->size);
 }
 
 
+
 /*************************************************
 *        Find the width of a string              *
 *************************************************/
@@ -590,7 +587,7 @@ return width;
 *************************************************/
 
 /* At present, the only Unicode characters recognized are those with values
-less than 65536 (i.e. two-bytes in binary). For fast lookup, we restrict this
+less than 65536 (i.e. two bytes in binary). For fast lookup, we restrict this
 to such values, and hope we never need to do anything else!
 
 Arguments:
@@ -604,13 +601,13 @@ Returns:        a kern value, or 0
 int
 font_kernwidth(int lastc, int c, vfontstr *vf)
 {
-unsigned int pair;
+uint32_t pair;
 int top, bot, mid;
 afontstr *af = vf->afont;
 
 if (lastc < 0 || lastc > 0xffff || c > 0xffff) return 0;
 
-pair = ((unsigned int)lastc << 16) | (unsigned int)c;
+pair = ((uint32_t)lastc << 16) | (uint32_t)c;
 
 bot = 0;
 top = af->kerncount;
@@ -813,7 +810,6 @@ Returns:      TRUE to continue processing
 BOOL
 font_assign(item *item_list, int fonts)
 {
-item *i;
 item *stop_at = NULL;
 paramstr *pm;
 vfontstr *vfontstack[FONTSTACKMAX + 1];
@@ -853,7 +849,7 @@ if (Ustrcmp(item_list->name, "index") == 0)
 
 /* Loop through all the other items */
 
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
   fontelstr *fe;
   uschar *name = i->name;
@@ -1215,7 +1211,7 @@ for (i = item_list; i != NULL; i = i->next)
           maintext_vfont.leading);
         }
 
-      if ((lf = font_used(v, NULL)) != v) free(v);
+      if ((lf = font_used(v, NULL)) != v) misc_free(v, sizeof(vfontstr));
 
       /* Having now found the font, for an itemized list with an overriding
       bullet mark, we must ensure that an appropriate auxiliary font is set up
@@ -1245,7 +1241,7 @@ for (i = item_list; i != NULL; i = i->next)
 this than to try to incorporate it above, where titles are handled separately
 from other text. */
 
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
   if (Ustrcmp(i->name, "#FILENAME") == 0)
     {
