@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains functions related to footnotes. */
 
@@ -10,7 +11,6 @@
 
 
 
-
 /*************************************************
 *      Remove newline before footnote[ref]       *
 *************************************************/
@@ -38,14 +38,12 @@ Returns:     nothing
 void
 footnote_remove_newline(item *i)
 {
-item *id;
-textblock *tb;
-for (id = i->prev; id != NULL; id = id->prev)
+for (item *id = i->prev; id != NULL; id = id->prev)
   {
   if (Ustrcmp(id->name, "/") == 0) continue;
   if (Ustrcmp(id->name, "#PCDATA") == 0)
     {
-    tb = id->p.txtblk;
+    textblock *tb = id->p.txtblk;
     if (tb->length > 0 && tb->string[tb->length-1] == '\n')
       tb->string[--(tb->length)] = 0;
     }
@@ -109,14 +107,13 @@ Returns:     TRUE if all is well
 BOOL
 footnote_insert_keys(item *item_list)
 {
-item *i, *id;
+item *id;
 
 DEBUG(D_any) debug_printf("Scanning for footnotes\n");
 
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
   item *idnext;
-  textblock *tb;
 
   if (Ustrcmp(i->name, "footnote") != 0) continue;
 
@@ -145,6 +142,7 @@ for (i = item_list; i != NULL; i = i->next)
   if (id == i->partner) error(71); else
     {
     item *ii;
+    textblock *tb;
 
     /* Insert a definition key. */
 
