@@ -2,10 +2,13 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: April 2023 */
 
-/* This header defines all the global functions, except the ucp and hyphenation
-ones. */
+/* This header defines all the global functions. */
+
+#ifndef INCLUDED_FUNCTIONS_H
+#define INCLUDED_FUNCTIONS_H
 
 #if SUPPORT_JPEG
 extern int           read_JPEG_file(FILE *, BOOL, void *);
@@ -14,11 +17,16 @@ extern void          put_scanline_someplace(uschar *, int, void *);
 #endif
 
 #if SUPPORT_PNG
-extern int           read_PNG_file(FILE *, uschar **);
+extern int           read_PNG_file(FILE *, uschar **, BOOL);
 extern void          give_png_image_data(int, int, int);
 extern void          write_png_data(FILE *);
 #endif
 
+extern void          Hyphen_Init(void);
+extern int           Hyphen_Prepare(uschar *);
+extern int           Hyphen_DePlural(uschar *, uschar *);
+extern int           Hyphen_Next(uschar *, int);
+
 extern BOOL          book_getdata(item *);
 extern BOOL          book_title_make(void);
 
@@ -79,7 +87,7 @@ extern BOOL          page_format(item *, item **, BOOL, BOOL, int *, uschar *);
 extern BOOL          para_format(item *);
 extern BOOL          para_identify(item *, int, item *);
 extern void          pin_change_columns(item *);
-extern unsigned int  pin_change_flags(item *, unsigned int);
+extern uint32_t      pin_change_flags(item *, uint32_t);
 extern void          pin_change_font_assign(item *);
 extern void          pin_change_layparm(item *);
 extern void          pin_change_list_params(item *, BOOL);
@@ -107,8 +115,9 @@ extern BOOL          read_write(uschar *);
 
 extern BOOL          ref_resolve(item *);
 extern BOOL          ref_set_pages(void);
-extern BOOL          revision_check(item *);
 
+extern BOOL          svg_find_size(FILE *, double *);
+extern void          svg_write(FILE *, FILE *);
 extern BOOL          sys_exists(uschar *);
 
 extern BOOL          table_identify(item *, item *);
@@ -121,5 +130,6 @@ extern tree_node    *tree_search(tree_node *, uschar *);
 extern BOOL          url_check(item *);
 
 extern BOOL          write_file(uschar *);
+#endif
 
 /* End of functions.h */
