@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: April 2023 */
 
 /* Allocate storage and initialize global variables, apart from those that are
 tables of some kind. Those are in datatables.c. */
@@ -78,6 +79,7 @@ item         *main_foot_item_list        = NULL;
 item         *main_head_item_list        = NULL;
 FILE         *main_hyphenfile            = NULL;
 item         *main_item_list             = NULL;
+memchainstr  *main_memory_chain          = NULL;
 int           main_page_count            = 0;
 int           memory_hwm                 = 0;
 int           memory_used                = 0;
@@ -544,8 +546,10 @@ hfstr         preface_headfoot = { US"&romanpage;",    /* foot_centre_recto */
                                    US"",               /* head_right_recto */
                                    US"" };             /* head_right_verso */
 
+BOOL          svg_listignored = FALSE;
+
 int           table_bot_frame_space = 4000;
-int           table_frame_thickness =  500;
+int           table_frame_thickness = 500;
 int           table_left_col_space  = 5000;
 int           table_overall_indent  = 0;
 int           table_right_col_space = 5000;
