@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains the code for doing hyphenation by reference to a
 dictionary. The original implementation was part of SGCAL. */
@@ -15,7 +16,7 @@ dictionary. The original implementation was part of SGCAL. */
 *              Data for hyphenation              *
 *************************************************/
 
-typedef unsigned int Key;
+typedef uint32_t Key;
 
 #define keyof(s) ((((Key)(s[0]))<<24)|(((Key)(s[1]))<<16)|(s[2]<<8)|s[3])
 
@@ -32,7 +33,8 @@ static unsigned int hy_indexsize;     /* size of index */
 *            Initialize hyphenation              *
 *************************************************/
 
-/* This function reads in the index to the hyphenation dictionary.
+/* This function reads the index to the hyphenation dictionary if one is
+present. If not, no hyphenation can happen.
 
 Arguments:  none
 Returns:    nothing
@@ -41,41 +43,32 @@ Returns:    nothing
 void
 Hyphen_Init(void)
 {
-unsigned int i;
+uschar line[20];
+long hy_indexoffset;
 
-/* Read in the hyphenation file index if a hyphenation file is present.
-If it is not, no hyphenation can be done. */
-
-if (main_hyphenfile != NULL)
-  {
-  uschar line[20];
-  long hy_indexoffset;
+if (main_hyphenfile == NULL) return;
 
 /* In newer versions of gcc, with FORTIFY_SOURCE set (the default in some
 environments), a warning is issued if the value of fgets() is ignored.
-Unfortunately, casting to (void) does not suppress the warning. To get round
-this, we use a fudge. */
+Casting to (void) does not suppress the warning. To get round this, we use a
+fudge. */
 
-  if (Ufgets(line, 20, main_hyphenfile)) {};
-  hy_indexsize = atoi(CS line);
-  hy_index = misc_malloc(hy_indexsize * sizeof(struct hyindex));
-  if (!hy_index)
-    {
-    fprintf(stderr,"Can't get store for hyphenation index\n");
-    exit(EXIT_FAILURE);
-    }
-  hy_index[0].key = 0;
-  hy_index[0].pos = 0;
-  for (i = 1; i < hy_indexsize; i++)
-    {
-    if (Ufgets(line, 20, main_hyphenfile)) {};  /* FORTIFY_SOURCE fudge */
-    hy_index[i].key = keyof(line);
-    hy_index[i].pos = atol(CS line+4);
-    }
+if (Ufgets(line, 20, main_hyphenfile)) {};
+hy_indexsize = atoi(CS line);
+hy_index = misc_malloc(hy_indexsize * sizeof(struct hyindex));
+hy_index[0].key = 0;
+hy_index[0].pos = 0;
 
-  hy_indexoffset = ftell(main_hyphenfile);
-  for (i = 0; i < hy_indexsize; i++) hy_index[i].pos += hy_indexoffset;
+for (unsigned int i = 1; i < hy_indexsize; i++)
+  {
+  if (Ufgets(line, 20, main_hyphenfile)) {};  /* FORTIFY_SOURCE fudge */
+  hy_index[i].key = keyof(line);
+  hy_index[i].pos = atol(CS line+4);
   }
+
+hy_indexoffset = ftell(main_hyphenfile);
+for (unsigned int i = 0; i < hy_indexsize; i++)
+  hy_index[i].pos += hy_indexoffset;
 }
 
 
@@ -84,7 +77,7 @@ this, we use a fudge. */
 *           Prepare word for hyphenation         *
 *************************************************/
 
-/* This procedure accepts a string which was delimited by spaces -- it removes
+/* This function accepts a string which was delimited by spaces -- it removes
 punctuation from either end, and also the suffix 's, so that the word can be
 hyphenated. The yield is the number of non-letters removed from the start of
 the word. This value must be added to the yields from Hyphen_Next() to get the
@@ -122,10 +115,8 @@ if (yield > 0)
   memmove(word, word + yield, len + 1);
   }
 
-/* Remove non-letters from the end of the word. We know there is
-at least one letter at the start. */
-
-while (!isalpha((int)word[len-1])) len--;
+/* Remove non-letters from the end of the word. We know there is at least one
+letter at the start. */
 
 ptr = word + len;
 for (;;)
@@ -154,8 +145,8 @@ return yield;
 *           De-plural for hyphenation            *
 *************************************************/
 
-/* This routine accepts a word and returns, in another vector,
-a de-pluralled form.
+/* This routine accepts a word and returns, in another vector, a de-pluralled
+form.
 
 Arguments:
   plural      the original word
@@ -244,10 +235,9 @@ uschar plainword[64];
 
 if ((int)Ustrlen(word) < 4 || hy_index == NULL) return -1;
 
-/* A value of zero for p indicates a call to find the last hyphenation
-point in a new word. We must scan the in-store index of first four
-letters (bytes) to find the place at which to start reading the hyphenation
-dictionary. */
+/* A value of zero for p indicates a call to find the last hyphenation point in
+a new word. We must scan the in-store index of first four letters (bytes) to
+find the place at which to start reading the hyphenation dictionary. */
 
 if (p == 0)
   {
@@ -288,7 +278,6 @@ if (p == 0)
     splitword[Ustrlen(splitword) - 1] = 0;
     while ((c = splitword[i++]) != 0) if (c != '-') plainword[j++] = c;
     plainword[j] = 0;
-
     if ((compare = Ustrcmp(word, plainword)) == 0) break;
     if (compare < 0) return -1;    /* No entry found, yield -1 */
     }
