@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains code for creating one or more indexes. */
 
@@ -72,6 +73,7 @@ return c;
 }
 
 
+
 /*************************************************
 *            Create collation data               *
 *************************************************/
@@ -98,7 +100,7 @@ int cs, us;
 
 if (cased_table != NULL) return;     /* Already done the job */
 
-DEBUG(D_index) debug_printf("Reading collation data\n");
+DEBUG(D_index) debug_printf("Reading index collation data\n");
 
 (void)misc_find_share(US"indexcollate", fn, TRUE);
 f = Ufopen(fn, "rb");
@@ -254,9 +256,9 @@ for (xii = xi->next, yii = yi->next; ; xii = xii->next, yii = yii->next)
   c = xii->p.txtblk->colour - yii->p.txtblk->colour;
   if (c != 0) return c;
 
-  c = (xii->p.txtblk->pin_flags &
+  c = (int)(xii->p.txtblk->pin_flags &
          (PIN_SSPERCENT|PIN_SUBSCRIPT|PIN_SUPERSCRIPT)) -
-      (yii->p.txtblk->pin_flags &
+      (int)(yii->p.txtblk->pin_flags &
          (PIN_SSPERCENT|PIN_SUBSCRIPT|PIN_SUPERSCRIPT));
   if (c != 0) return c;
   }
@@ -290,7 +292,6 @@ return ixcompare_textfont(xi, yi);
 
 
 
-
 /*************************************************
 *        Compare function for index sorting      *
 *************************************************/
@@ -376,6 +377,7 @@ return ptrs[0] != NULL;
 }
 
 
+
 /*************************************************
 *     Add page number(s) or "see" to output      *
 *************************************************/
@@ -473,7 +475,7 @@ stop when we hit the <index> item for the index we are creating.
 
 Arguments:
   item_list    the list to be processed (the main list)
-  index_item   the item that prints this index
+  index_item   the item that outputs this index
 
 Returns:       TRUE to continue processing; FALSE to stop
                (currently always TRUE)
