@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains a number of miscellaneous small utility functions. */
 
@@ -15,7 +16,10 @@
 *               Malloc with check                *
 *************************************************/
 
-/* The program dies if the memory is not available.
+/* The program dies if the memory is not available. At the start of each block
+we add a memchainstr to make a two-way chain. Blocks that are freed are taken
+out of the chain; any that are left at the end are freed by an atexit()
+function.
 
 Argument:    size required
 Returns:     pointer
@@ -24,11 +28,17 @@ Returns:     pointer
 void *
 misc_malloc(int size)
 {
-void *yield = malloc(size);
+memchainstr *yield;
+size += sizeof(memchainstr);
+yield = malloc(size);
 if (yield == NULL) (void)error(1, size);   /* Fatal error */
 memory_used += size;
 if (memory_used > memory_hwm) memory_hwm = memory_used;
-return yield;
+yield->next = main_memory_chain;
+yield->prev = NULL;
+if (main_memory_chain != NULL) main_memory_chain->prev = yield;
+main_memory_chain = yield;
+return (void *)((char *)yield + sizeof(memchainstr));
 }
 
 
@@ -37,7 +47,7 @@ return yield;
 *                Free                            *
 *************************************************/
 
-/* This function exists so we can trap it if necessary
+/* Remove the block from the remembered chain before freeing it.
 
 Argument:
   ptr       the pointer to free
@@ -49,8 +59,19 @@ Returns:    nothing
 void
 misc_free(void *ptr, int size)
 {
-free(ptr);
-memory_used -= size;
+memchainstr *p = (memchainstr *)((char *)ptr - sizeof(memchainstr));
+
+for (memchainstr *pp = main_memory_chain; pp != NULL; pp = pp->next)
+  if (pp == p) break;
+
+if (p == NULL) error(118);  /* Hard */
+
+if (p->next != NULL) p->next->prev = p->prev;
+if (p == main_memory_chain) main_memory_chain = p->next;
+  else p->prev->next = p->next;
+
+free(p);
+memory_used -= size + sizeof(memchainstr);
 }
 
 
@@ -214,7 +235,6 @@ paramstr *
 misc_param_find(item *i, uschar *name)
 {
 paramstr *p;
-
 for (p = i->p.param; p != NULL; p = p->next)
   {
   if (Ustrcmp(p->name, name) == 0)
@@ -249,7 +269,6 @@ Returns:     pointer to lengthstring item or NULL if no title found
 lengthstring *
 misc_find_title(item *i, uschar *titlename)
 {
-item *ii;
 lengthstring *ls;
 uschar *p;
 int count = 0;
@@ -285,13 +304,13 @@ for(;;)
   i = i->partner->next;
   }
 
-for (ii = i->next; ii != i->partner; ii = ii->next)
+for (item *ii = i->next; ii != i->partner; ii = ii->next)
   if (Ustrcmp(ii->name, "#PCDATA") == 0) count += ii->p.txtblk->length;
 
 ls = misc_malloc(sizeof(lengthstring) + count);
 p = ls->value;
 
-for (ii = i->next; ii != i->partner; ii = ii->next)
+for (item *ii = i->next; ii != i->partner; ii = ii->next)
   if (Ustrcmp(ii->name, "#PCDATA") == 0)
     {
     uschar *string = ii->p.txtblk->string;
@@ -394,8 +413,7 @@ Returns:   TRUE if it's one of the specials
 BOOL
 misc_istext_elname(uschar *s)
 {
-int k;
-for (k = 0; text_elements[k] != NULL; k++)
+for (int k = 0; text_elements[k] != NULL; k++)
   {
   int len = Ustrlen(text_elements[k]);
   if (Ustrncmp(s, text_elements[k], len) == 0 &&
@@ -432,7 +450,6 @@ return (*s == 0)? yield : -1;
 *************************************************/
 
 /*
-
 Arguments:
   s         the string
   p         where to put the terminator pointer
@@ -468,10 +485,9 @@ return yield;
 *************************************************/
 
 /*
-
 Arguments:
   fp        the fixed-point number
-  s         the following string
+  s         the following string, giving the units
 
 Returns:    the scaled number, or -1 on error
 */
@@ -530,10 +546,9 @@ Returns:       TRUE if all went well
 BOOL
 misc_get_dimensions(int n, uschar *s, int *iptr, BOOL give_error)
 {
-int k;
 uschar *sorig = s;
 
-for (k = 0; k < n; k++)
+for (int k = 0; k < n; k++)
   {
   int x;
   int sign = 1;
@@ -595,7 +610,7 @@ Returns:     number of characters placed in the buffer
 int
 misc_ord2utf8(int cvalue, uschar *buffer)
 {
-register int i, j;
+int i, j;
 for (i = 0; i < 6; i++) if (cvalue <= utf8_table1[i]) break;
 buffer += i;
 for (j = i; j > 0; j--)
@@ -788,6 +803,7 @@ return TRUE;
 }
 
 
+
 /*************************************************
 *         Interpret a colour specification       *
 *************************************************/
