@@ -2,13 +2,14 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This header file contains type definitions and macros that I use as
 "standard" in the code of sdop and its utilities. */
 
-#ifndef MYTYPES_H
-#define MYTYPES_H
+#ifndef INCLUDED_MYTYPES_H
+#define INCLUDED_MYTYPES_H
 
 #define FALSE         0
 #define TRUE          1
@@ -25,9 +26,9 @@ the arguments of printf-like functions. This is done by a macro. */
 #endif
 
 
-/* Some operating systems (naughtily, imo) include a definition for "uchar" in
-the standard header files, so we use "uschar". Solaris has u_char in
-sys/types.h. This is just a typing convenience, of course. */
+/* Some operating systems (used to?) include a definition for "uchar" in the
+standard header files, so we use "uschar". Solaris has u_char in sys/types.h.
+This is just a typing convenience, of course. */
 
 typedef int BOOL;
 typedef unsigned char uschar;
