@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains functions for doing things to pages. */
 
@@ -26,7 +27,6 @@ static BOOL footnote_encountered;
 
 
 
-
 /*************************************************
 *       Find extra space needed after title      *
 *************************************************/
@@ -85,7 +85,6 @@ return extra;
 
 
 
-
 /*************************************************
 *          Find level of an index line           *
 *************************************************/
@@ -200,6 +199,7 @@ compilers complain. */
 
 for (j = ip->next; j != ip->partner; j = j->next)
   if (Ustrcmp(j->name, "title") == 0) break;
+
 if (j != ip->partner)
   {
   for (k = j->next; k != j->partner; k = k->next)
@@ -271,6 +271,11 @@ for (j = ip->next; j != ip->partner; j = j->next)
     }
   }    /* End of scan for row depths */
 
+/* The variable frcount (number of rows in a foot) is not currently used, so we
+need to avoid a compiler warning. */
+
+(void)frcount;
+
 /* Not finding the table's data block is a hard error. */
 
 if (td == NULL) (void)error(42);
@@ -788,6 +793,7 @@ return ACCEPT_NO;
 }
 
 
+
 /*************************************************
 *                Create pages                    *
 *************************************************/
