@@ -2,14 +2,13 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
-/* Last modified: August 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains functions for doing things to paragraphs. */
 
 #include "sdop.h"
 
-
 /* Looseness parameters for analyzing lines. */
 
 #define L_BAD     95
@@ -40,8 +39,7 @@ Returns:   the <attribution> element, or NULL
 static item *
 find_attribution(item *i)
 {
-item *ii;
-for (ii = i->next; ii != i->partner; ii = ii->next)
+for (item *ii = i->next; ii != i->partner; ii = ii->next)
   if (Ustrcmp(ii->name, "attribution") == 0) return ii;
 return NULL;
 }
@@ -67,8 +65,7 @@ Returns:    nothing
 static void
 add_rules(item *begin, item *end)
 {
-item *i;
-for (i = begin->next; i != end; i = i->next)
+for (item *i = begin->next; i != end; i = i->next)
   {
   if (Ustrcmp(i->name, "#PCPARA") == 0)
     {
@@ -76,7 +73,7 @@ for (i = begin->next; i != end; i = i->next)
     break;
     }
   }
-for (i = end->prev; i != begin; i = i->prev)
+for (item *i = end->prev; i != begin; i = i->prev)
   {
   if (Ustrcmp(i->name, "#PCPARA") == 0)
     {
@@ -439,7 +436,6 @@ Returns:      TRUE to continue processing
 BOOL
 para_identify(item *item_list, int fonts, item *stop_at)
 {
-item *i;
 item *saved_attribution = NULL;
 layoutparam *lpptr;
 layoutparam *temp_lpptr = NULL;
@@ -493,7 +489,7 @@ if (Ustrcmp(item_list->name, "index") == 0)
 
 /* Now the rest of the list */
 
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
   uschar *name = i->name;
 
@@ -1725,7 +1721,6 @@ return tb;
 
 
 
-
 /*************************************************
 *             Polish a filled paragraph          *
 *************************************************/
@@ -1916,7 +1911,6 @@ Returns:     TRUE to continue processing
 BOOL
 para_format(item *item_list)
 {
-item *i;
 item *stop_at = NULL;
 paragraph *pg;
 tdatastr *td = NULL;
@@ -1952,7 +1946,7 @@ if (Ustrcmp(item_list->name, "index") == 0) stop_at = item_list->partner;
 /* Process the items, starting at the second, so as to skip the initial dummy
 or <index> item. */
 
-for (i = item_list->next; i != NULL; i = i->next)
+for (item *i = item_list->next; i != NULL; i = i->next)
   {
   layoutparam *lp;
   textblock *tb;
