@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains code for the support of PNG images. */
 
@@ -38,14 +39,14 @@ information about the image. It must *not* close the file.
 Arguments:
   f        the open file
   msg      where to return an error message
+  writing  TRUE when actually writing, FALSE when just measuring
 
 Returns:   TRUE on success, FALSE on failure
 */
 
 int
-read_PNG_file(FILE *f, uschar **msg)
+read_PNG_file(FILE *f, uschar **msg, BOOL writing)
 {
-int i;
 uschar hdr[8];
 
 /* Check that we really do have a PNG file. Avoid gcc warning in environments
@@ -70,6 +71,7 @@ if (png_ptr == NULL)
 info_ptr = png_create_info_struct(png_ptr);
 if (info_ptr == NULL)
   {
+  png_destroy_read_struct(&png_ptr, NULL, NULL);
   *msg = US"failure of png_create_info_struct()";
   return FALSE;
   }
@@ -87,18 +89,24 @@ png_read_info(png_ptr, info_ptr);
 image_width = png_get_image_width(png_ptr, info_ptr);
 image_height = png_get_image_height(png_ptr, info_ptr);
 image_rowbytes = png_get_rowbytes(png_ptr, info_ptr);
-
 give_png_image_data(image_width, image_height, image_rowbytes);
-if (setjmp(png_jmpbuf(png_ptr)))
+
+/* Don't get memory or read the data when just measuring. */
+
+if (writing)
   {
-  *msg = US"failure to read PNG image data";
-  return FALSE;
+  if (setjmp(png_jmpbuf(png_ptr)))
+    {
+    *msg = US"failure to read PNG image data";
+    return FALSE;
+    }
+  row_pointers = (png_bytep *)malloc(sizeof(png_bytep) * image_height);
+  for (int i = 0; i < image_height; i++)
+    row_pointers[i] = (png_byte *)malloc(image_rowbytes);
+  png_read_image(png_ptr, row_pointers);
   }
 
-row_pointers = (png_bytep *)malloc(sizeof(png_bytep) * image_height);
-for (i = 0; i < image_height; i++)
-  row_pointers[i] = (png_byte *)malloc(image_rowbytes);
-png_read_image(png_ptr, row_pointers);
+png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 
 return TRUE;
 }
@@ -119,10 +127,9 @@ Returns:   nothing
 void
 write_png_data(FILE *outfile)
 {
-int i, j;
-for (i = 0; i < image_height; i++)
+for (int i = 0; i < image_height; i++)
   {
-  for (j = 0; j < image_rowbytes; j++)
+  for (int j = 0; j < image_rowbytes; j++)
     {
     if ((j & 31) == 0) (void)fprintf(outfile, "\n");
     (void)fprintf(outfile, "%02x", (unsigned int)row_pointers[i][j]);
@@ -130,7 +137,6 @@ for (i = 0; i < image_height; i++)
   (void)fprintf(outfile, "\n");
   free(row_pointers[i]);
   }
-
 free(row_pointers);
 }
 
