@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module handles initial processing of prefaces. */
 
@@ -30,7 +31,6 @@ Returns:     TRUE
 BOOL
 preface_process(void)
 {
-item *i;
 item *ep;
 item *pi = NULL;
 item *pilast = NULL;
@@ -43,7 +43,7 @@ if (preface_item_list == NULL)
 
 /* Get a list of processing instructions. */
 
-for (i = main_item_list; i != preface_item_list; i = i->next)
+for (item *i = main_item_list; i != preface_item_list; i = i->next)
   {
   item *ii;
   if (Ustrcmp(i->name, "?sdop") != 0) continue;
