@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020  */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains code for resolving cross references. */
 
@@ -10,7 +11,6 @@
 #include "sdop.h"
 
 
-
 /*************************************************
 *               Resolve references               *
 *************************************************/
@@ -24,12 +24,11 @@ Returns:      TRUE/FALSE
 BOOL
 ref_resolve(item *item_list)
 {
-item *i, *new, *refitem;
-
 DEBUG(D_any) debug_printf("Resolving references\n");
 
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
+  item *refitem;
   paramstr *p;
   textblock *tb;
   tree_node *tn;
@@ -91,7 +90,7 @@ for (i = item_list; i != NULL; i = i->next)
 
     if (ref[0] != 0)
       {
-      new = misc_malloc(sizeof(item));
+      item *new = misc_malloc(sizeof(item));
       new->partner = new;
       new->linenumber = i->linenumber;
       new->flags = 0;
@@ -146,17 +145,16 @@ static item** list_of_lists[] =   /* These are the lists of items for */
 
 int pagenumber = 0;
 int ypos = 0;
-item *i, **ip, ***ipp;
 
 if (!xref_links) return TRUE;     /* Disabled */
 
-for (ipp = list_of_lists, ip = *ipp++; ip != NULL; ip = *ipp++)
+for (item ***ipp = list_of_lists, **ip = *ipp++; ip != NULL; ip = *ipp++)
   {
   if (*ip == NULL) continue;      /* Empty list (not even a dummy header) */
 
   /* Start at the first #PDATA (page data) item (if present) */
 
-  for (i = (*ip)->next; i != NULL; i = i->next)
+  for (item *i = (*ip)->next; i != NULL; i = i->next)
     {
     paramstr *p;
     tree_node *tn;
