@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: April 2023 */
 
 /* This module contains the main program and initialization functions. */
 
@@ -36,6 +37,7 @@ static bit_table debug_options[] = {
   { US"param",           D_param },
   { US"read",            D_read },
   { US"ref",             D_ref },
+  { US"svg",             D_svg },
   { US"title",           D_title },
   { US"toc",             D_toc },
   { US"write",           D_write }
@@ -57,7 +59,6 @@ static int template_count = sizeof(templates)/sizeof(templatestr);
 
 
 
-
 /*************************************************
 *            Page list decoding                  *
 *************************************************/
@@ -218,8 +219,6 @@ return TRUE;  /* Should never get here, but keep compiler happy */
 static void
 usage(void)
 {
-int i;
-
 (void)fprintf(stderr,
   "Usage: sdop [options] [input file]\n"
   "  -d<debug-options>         produce debug output (no space after -d)\n"
@@ -241,7 +240,7 @@ int i;
 "\napplies to all output pages. The -S option overrides SDOP_SHARE.\n");
 
 (void)fprintf(stderr, "\nDebug options (+ to add, - to subtract):");
-for (i = 0; i < debug_options_count; i++)
+for (int i = 0; i < debug_options_count; i++)
   {
   if ((i & 7) == 0) (void)fprintf(stderr, "\n  ");
   (void)fprintf(stderr, " %s", debug_options[i].name);
@@ -251,7 +250,6 @@ for (i = 0; i < debug_options_count; i++)
 
 
 
-
 /*************************************************
 *          Command line argument decoding        *
 *************************************************/
@@ -373,6 +371,7 @@ return TRUE;
 }
 
 
+
 /*************************************************
 *         Initialize hyphenation dictionary      *
 *************************************************/
@@ -407,10 +406,9 @@ Returns:    TRUE/FALSE
 static BOOL
 sdop_init_templates(void)
 {
-int i;
 uschar tfilename[128];
 internal_processing = TRUE;
-for (i = 0; i < template_count; i++)
+for (int i = 0; i < template_count; i++)
   {
   item *item_list = *(templates[i].anchor) = misc_dummy_item();
   (void)misc_find_share(templates[i].filename, tfilename, TRUE);
@@ -431,10 +429,10 @@ return TRUE;
 
 
 /*************************************************
-*      Print unknown element/attribute tree      *
+*      Output unknown element/attribute tree     *
 *************************************************/
 
-/* Prints the tree of unknown elements and attributes, calling itself
+/* Outputs the tree of unknown elements and attributes, calling itself
 recursively to get them in order.
 
 Argument:    a tree node
@@ -442,9 +440,9 @@ Returns:     nothing
 */
 
 static void
-print_unknown_tree(tree_node *tn)
+write_unknown_tree(tree_node *tn)
 {
-if (tn->left != NULL) print_unknown_tree(tn->left);
+if (tn->left != NULL) write_unknown_tree(tn->left);
 if (tn->name[0] == '+')
   {
   uschar *eptr = Ustrrchr(tn->name, ':');
@@ -460,7 +458,7 @@ else
   {
   fprintf(stderr, "<%s>\n", tn->name);
   }
-if (tn->right != NULL) print_unknown_tree(tn->right);
+if (tn->right != NULL) write_unknown_tree(tn->right);
 }
 
 
@@ -515,6 +513,65 @@ return TRUE;
 
 
 
+/*************************************************
+*        Scan items and check revisionflag       *
+*************************************************/
+
+/* This function scans the input document and handles the revisionflag
+attribute, which is a common attribute that is allowed on all elements. We only
+support "changed" at present - the check for other values happens with the
+general check for supported elements/attributes.
+
+Argument:      the first item in the list to be processed
+Returns:       TRUE to continue processing; FALSE to stop
+               (currently always TRUE)
+*/
+
+static BOOL
+revision_check(item *item_list)
+{
+DEBUG(D_any) debug_printf("Processing revisionflag attributes\n");
+
+for (item *i = item_list; i != NULL; i = i->next)
+  {
+  paramstr *p;
+  if (i->name[0] == '/' || i->name[0] == '#') continue;
+  if ((p = misc_param_find(i, US"revisionflag")) == NULL) continue;
+
+  if (Ustrcmp(p->value, "changed") == 0)
+    {
+    for (item *ii = i->next; ii != i->partner; ii = ii->next)
+      {
+      if (Ustrcmp(ii->name, "#PCDATA") == 0)
+        ii->p.txtblk->pin_flags |= PIN_REVCH;
+      }
+    }
+  }
+
+return TRUE;
+}
+
+
+
+/*************************************************
+*         Function called to tidy on exit        *
+*************************************************/
+
+/* This cleans up memory that wasn't freed while processing. */
+
+static void
+tidy_up(void)
+{
+while (main_memory_chain != NULL)
+   {
+   memchainstr *m = main_memory_chain;
+   main_memory_chain = m->next;
+   free(m);
+   }
+}
+
+
+
 /*************************************************
 *          Entry point and main program          *
 *************************************************/
@@ -536,7 +593,10 @@ if (share != NULL)
   Ustrcpy(sdop_share, share);
   }
 
+if (atexit(tidy_up) != 0) error(117);   /* Hard */
+
 yield = sdop_decode_arg(argc, argv);
+DEBUG(D_svg) svg_listignored = TRUE;
 
 main_item_list  = misc_dummy_item();
 title_item_list = misc_dummy_item();
@@ -673,12 +733,10 @@ some of them. */
 
 if (yield)
   {
-  item *i;
-  for (i = main_item_list; i != NULL; i = i->next)
+  for (item *i = main_item_list; i != NULL; i = i->next)
     {
-    paramstr *p;
     if (Ustrcmp(i->name, "?sdop") != 0) continue;
-    for (p = i->p.param; p != 0; p = p->next)
+    for (paramstr *p = i->p.param; p != 0; p = p->next)
       {
       if (!p->seen)
         {
@@ -691,13 +749,10 @@ if (yield)
 
 /* It should be OK to do this warning always. */
 
-if (warn_unsupported)
+if (warn_unsupported && unknown_element_tree != NULL)
   {
-  if (unknown_element_tree != NULL)
-    {
-    fprintf(stderr, "sdop: Ignored unrecognized elements and attributes:\n");
-    print_unknown_tree(unknown_element_tree);
-    }
+  fprintf(stderr, "sdop: Ignored unrecognized elements and attributes:\n");
+  write_unknown_tree(unknown_element_tree);
   }
 
 /* If there were errors that did not prevent the output being generated, give a
