@@ -2,30 +2,30 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
-
-/* I wrote this because I was frustrated at the lack of free software for
-processing DocBook which could produce really nice typographic PostScript
-output. Much of the text formatting logic is taken from SGCAL. */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: April 2023 */
 
+/* Main SDoP header file, included by all modules. */
 
 #ifndef INCLUDED_SDOP_H
 #define INCLUDED_SDOP_H
 
-#define SDOP_VERSION "0.90"
-#define SDOP_DATE    "20-August-2020"
+#define SDOP_VERSION "1.10"
+#define SDOP_DATE    "29-April-2023"
 
-/* General header file for all modules */
+/* Standard C headers */
 
 #include <ctype.h>
+#include <errno.h>
 #include <limits.h>
+#include <math.h>
 #include <stdarg.h>
 #include <stddef.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <errno.h>
 
 /* These are some parameters that specify sizes of things in the code. They
 must appear before including the local headers. */
@@ -46,24 +46,20 @@ headers, but they might as well be together with those above. */
 
 #define MAXHEADFOOTPARA      32
 #define MAXSECTDEPTH         10
-
 #define MAXLISTNEST          10
 
 #define TOC_LINE_STRING_COUNT 6
 
 #define DEFAULT_PAGE_COLSEP  16000
 
-
 /* More header files for sdop */
 
 #include "mytypes.h"
 #include "structs.h"
 #include "globals.h"
 #include "functions.h"
-#include "hyphen.h"
 #include "ucp.h"
 
-
 /* Error codes */
 
 #define ec_noerror   0
@@ -72,14 +68,12 @@ headers, but they might as well be together with those above. */
 #define ec_failed    3
 #define ec_disaster  4
 
-
 /* Document types */
 
 #define DOC_UNSET         0
 #define DOC_BOOK          1
 #define DOC_ARTICLE       2
 
-
 /* The following value must not be less than 256. Characters whose Unicode
 values are less than this limit are treated specially in two ways:
 
@@ -103,7 +97,7 @@ It should be one that is always available in the base font, with code less that
 
 /* This defines the "width" that is placed in the low-character width table for
 unknown characters. It marks the character as unknown. We cannot use a negative
-number, because there are fonts containing characters that have negative
+number, because there may be fonts containing characters that have negative
 widths. */
 
 #define WIDTH_UNKNOWN  0x7fffffff
@@ -167,13 +161,13 @@ outputting details of head/foot/toc template files every time. */
 #define D_param        0x00008000
 #define D_read         0x00010000
 #define D_ref          0x00020000
-#define D_title        0x00040000
-#define D_toc          0x00080000
-#define D_write        0x00100000
+#define D_svg          0x00040000
+#define D_title        0x00080000
+#define D_toc          0x00100000
+#define D_write        0x00200000
 
 #define D_all         (0xffffffff & ~D_internal)
 
-
 /* Flags in items */
 
 #define IF_FONTSET     0x00000001   /* Item changes font */
@@ -189,7 +183,6 @@ outputting details of head/foot/toc template files every time. */
 #define IF_RULEBELOW   0x00000400   /* This para has a rule below */
 #define IF_DUMMYDATA   0x00000800   /* The is dummy #PCDATA item */
 
-
 /* Flags in table structures */
 
 #define TDF_BOTFRAME   0x00000001
@@ -207,23 +200,22 @@ outputting details of head/foot/toc template files every time. */
 
 #define TDF_DEFAULT    (TDF_BOTFRAME|TDF_TOPFRAME|TDF_SIDEFRAME)
 
+/* Processing instruction flags in textblocks. The top seven bits are used for
+the percentage to go up/down for subscripts or superscripts. */
 
-/* Processing instruction flags in textblocks. The top seven bits are used
-for the percentage to go up/down for subscripts or superscripts. */
-
-#define PIN_KERN         0x00000001
-#define PIN_HYPH         0x00000002
-#define PIN_SOFTOF       0x00000004   /* Table: warn for soft overflow */
-#define PIN_HARDOF       0x00000008   /* Table: warn for hard overflow */
-#define PIN_REVCH        0x00000010   /* revisionflag="changed" */
-#define PIN_FNKEYREF     0x00000020   /* Foonote key reference */
-#define PIN_FNKEYDEF     0x00000040   /* Footnote key definition */
-#define PIN_FNREFREF     0x00000080   /* Reference from <footnoteref> */
-#define PIN_SUPERSCRIPT  0x00000100
-#define PIN_SUBSCRIPT    0x00000200
-#define PIN_XREF         0x00000400   /* This is crossreference text */
-#define PIN_IREF         0x00000800   /* This is index reference text */
-#define PIN_SSPERCENT    0xFE000000   /* Seven-bit number */
+#define PIN_KERN         0x00000001u
+#define PIN_HYPH         0x00000002u
+#define PIN_SOFTOF       0x00000004u   /* Table: warn for soft overflow */
+#define PIN_HARDOF       0x00000008u   /* Table: warn for hard overflow */
+#define PIN_REVCH        0x00000010u   /* revisionflag="changed" */
+#define PIN_FNKEYREF     0x00000020u   /* Foonote key reference */
+#define PIN_FNKEYDEF     0x00000040u   /* Footnote key definition */
+#define PIN_FNREFREF     0x00000080u   /* Reference from <footnoteref> */
+#define PIN_SUPERSCRIPT  0x00000100u
+#define PIN_SUBSCRIPT    0x00000200u
+#define PIN_XREF         0x00000400u   /* This is crossreference text */
+#define PIN_IREF         0x00000800u   /* This is index reference text */
+#define PIN_SSPERCENT    0xFE000000u   /* Seven-bit number */
 
 #define SSPERCENT_SHIFT    25
 #define SSPERCENT_DEFAULT  33
@@ -241,12 +233,10 @@ for the percentage to go up/down for subscripts or superscripts. */
 #define OLF_ADD_HYPHEN 0x00000002
 #define OLF_RULE       0x00000004
 
-
 /* List numerations */
 
 enum { LN_ARABIC, LN_alpha, LN_roman, LN_ALPHA, LN_ROMAN };
 
-
 /* These definitions must be kept in step with the vectors in datatables.c. */
 
 enum { FFAM_SERIF, FFAM_SANSERIF, FFAM_MONO, FFAM_SPECIAL, FFAM_EXOTIC };
@@ -254,8 +244,8 @@ enum { FTYPE_ROMAN, FTYPE_ITALIC, FTYPE_BOLD, FTYPE_BOLDITALIC, FTYPE_SPECIAL };
 
 enum { J_UNSET, J_LEFT, J_CENTRE, J_RIGHT, J_BOTH, J_CHAR };
 
-#define FONTS_MAIN      0   /* These values are offsets into the vfontstr */
-#define FONTS_SMALL     8
+#define FONTS_MAIN      0
+#define FONTS_SMALL     8   /* These values are offsets into the vfontstr */
 #define FONTS_TOC      16   /* tables and are used as the 2nd argument to */
 #define FONTS_INDEX    24   /* font_assign() and para_identify(). */
 #define FONTS_TITLE    32
@@ -285,6 +275,7 @@ enum { J_UNSET, J_LEFT, J_CENTRE, J_RIGHT, J_BOTH, J_CHAR };
 #define IFORM_EPS   1
 #define IFORM_JPG   2
 #define IFORM_PNG   3
+#define IFORM_SVG   4
 
 /* Values for main and footnote layout parameter selection. The last one must
 be LP_FOOTNOTE. These are used to index into lptable. */
@@ -307,7 +298,6 @@ enum { LP_FORMALPARA,   LP_PARA,         LP_BLOCKQUOTE,   LP_SIDEBAR,
 #define MULDIV(a,b,c) \
   ((int)((((double)((int)(a)))*((double)((int)(b))))/((double)((int)(c)))))
 
-
 /* Macro for testing for "section" or "sectN" */
 
 #define ISSECT(n) \
@@ -319,7 +309,7 @@ enum { LP_FORMALPARA,   LP_PARA,         LP_BLOCKQUOTE,   LP_SIDEBAR,
     ) \
   )
 
-/* Macros for loading UTF-8 characters */
+/* ------------ UTF-8 and UCD macros ------------ */
 
 /* Get the next UTF-8 character, not advancing the pointer. */
 
@@ -378,17 +368,16 @@ it is. */
 
 #define BACKCHAR(ptr) while((*ptr & 0xc0) == 0x80) ptr--;
 
-/* UCD access macros - copied from PCRE */
+/* UCD access macros - copied from PCRE2. We are only interested in the
+character category, for detecting letters when hyphenating. */
 
 #define UCD_BLOCK_SIZE 128
 #define GET_UCD(ch) (ucd_records + \
-        ucd_stage2[ucd_stage1[(ch) / UCD_BLOCK_SIZE] * \
-        UCD_BLOCK_SIZE + ch % UCD_BLOCK_SIZE])
+        ucd_stage2[ucd_stage1[(int)(ch) / UCD_BLOCK_SIZE] * \
+        UCD_BLOCK_SIZE + (int)ch % UCD_BLOCK_SIZE])
 
 #define UCD_CHARTYPE(ch)  GET_UCD(ch)->chartype
-#define UCD_SCRIPT(ch)    GET_UCD(ch)->script
 #define UCD_CATEGORY(ch)  ucp_gentype[UCD_CHARTYPE(ch)]
-#define UCD_OTHERCASE(ch) (ch + GET_UCD(ch)->other_case)
 
 #endif   /* INCLUDED_SDOP_H */
 
