@@ -2,13 +2,25 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
+
+#ifndef INCLUDED_STRUCTS_H
+#define INCLUDED_STRUCTS_H
 
 /* This module contains definitions of structures that are used throughout the
 program. */
 
 struct item;                   /* For forward reference */
 
+/* Structure used at the start of malloc'ed blocks so that they can all be
+chained for freeing on exit. */
+
+typedef struct memchainstr {
+  struct memchainstr *next;
+  struct memchainstr *prev;
+} memchainstr;
+
 /* Structure for table of supported elements */
 
 typedef struct elliststr {
@@ -33,8 +45,8 @@ typedef struct tree_node {
 /* Items in a kerning table */
 
 typedef struct kerntablestr {
-  unsigned int pair;
-  int kwidth;
+  uint32_t pair;
+  int32_t kwidth;
 } kerntablestr;
 
 /* Entries in the character name to Unicode code point table */
@@ -115,7 +127,7 @@ typedef struct textblock {
   struct textblock *next;      /* Chain for paragraphs and formatted lines */
   struct textblock *lastin;    /* Last input textblock in an output one */
   vfontstr *vfont;             /* Point to virtual font */
-  unsigned int pin_flags;      /* Processing instruction flags */
+  uint32_t pin_flags;          /* Processing instruction flags */
   int colour;                  /* Three 10-bit fields (values 0-1000) */
   int length;                  /* Length of string */
   uschar string[1];            /* The string data */
@@ -218,10 +230,10 @@ typedef struct indexstr {
 } indexstr;
 
 /* The input file is read into a chain of items. Most of them are DocBook
-markup items, but the input text is held in #PCDATA items, formatted
-paragraphs are held in #PCPARA items, table information is held in #TDATA
-items, page data in #PDATA items, raw chapter and section title strings in
-#RAWTITLE items, and there may be others. */
+markup items, but the input text is held in #PCDATA items, formatted paragraphs
+are held in #PCPARA items, table information is held in #TDATA items, page data
+in #PDATA items, raw chapter and section title strings in #RAWTITLE items, and
+there may be others. */
 
 typedef struct item {
   struct item *next;
@@ -324,12 +336,20 @@ typedef struct colourstr {
   int B;
 } colourstr;
 
-/* Unicode character database (UCD) */
+/* Unicode character database (UCD) record format. This is copied from PCRE2,
+but is used only for detecting letters when hyphenating. All the other
+information (such as script) is not relevant. */
 
 typedef struct {
-  uschar script;
-  uschar chartype;
-  unsigned int other_case;
+  uint8_t script;     /* ucp_Arabic, etc. */
+  uint8_t chartype;   /* ucp_Cc, etc. (general categories) */
+  uint8_t gbprop;     /* ucp_gbControl, etc. (grapheme break property) */
+  uint8_t caseset;    /* offset to multichar other cases or zero */
+  int32_t other_case; /* offset to other case, or zero if none */
+  uint16_t scriptx_bidiclass; /* script extension (11 bit) and bidi class (5 bit) values */
+  uint16_t bprops;    /* binary properties offset */
 } ucd_record;
 
+#endif
+
 /* End of structs.h */
