@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains functions for handling tables. */
 
@@ -29,10 +30,9 @@ Returns:     the group item, or NULL
 static item *
 table_check_onegroup(item *t, item **thptr, item **tfptr, item **tbptr)
 {
-item *i;
 item *tg = NULL;
 
-for (i = t; i != t->partner; i = i->next)
+for (item *i = t; i != t->partner; i = i->next)
   {
   if (Ustrcmp(i->name, "thead") == 0)
     {
@@ -59,6 +59,7 @@ for (i = t; i != t->partner; i = i->next)
     tg = i;
     }
   }
+
 if (tg == NULL) (void)error(34);   /* Missing tgroup */
 return tg;
 }
@@ -141,15 +142,14 @@ Returns:    the depth
 int
 table_row_depth(tdatastr *td, item *i)
 {
-item *k, *kk;
 int celldepth;
 int rowdepth = 0;
 
-for (k = i->next; k != i->partner; k = k->next)
+for (item *k = i->next; k != i->partner; k = k->next)
   {
   if (Ustrcmp(k->name, "entry") != 0) continue;
   celldepth = 0;
-  for (kk = k->next; kk != k->partner; kk = kk->next)
+  for (item *kk = k->next; kk != k->partner; kk = kk->next)
     {
     outputline *ol;
     if (Ustrcmp(kk->name, "#PCPARA") != 0) continue;
@@ -199,7 +199,6 @@ Returns:     TRUE if all went well; FALSE otherwise, to stop further processing
 BOOL
 table_identify(item *item_list, item *stop_at)
 {
-item *i;
 int fnindent = 0;
 int linewidth = page_linewidth;
 int colwidths[256];
@@ -218,13 +217,13 @@ if (Ustrcmp(item_list->name, "index") == 0) stop_at = item_list->partner;
 
 /* Loop for all the tables in the document. */
 
-for (i = item_list->next; i != NULL; i = i->next)
+for (item *i = item_list->next; i != NULL; i = i->next)
   {
   uschar *name = i->name;
   int colcount;
   int collast;
   int width_total;
-  int colnum, rownum, toprowsize, x;
+  int colnum, rownum, toprowsize;
   int align_default;
   int align_char_default;
   int align_charoff_default;
@@ -312,7 +311,7 @@ for (i = item_list->next; i != NULL; i = i->next)
 
   /* Mark the columns unset */
 
-  for (x = 1; x <= colcount; x++)
+  for (int x = 1; x <= colcount; x++)
     {
     colwidths[x] = 0;
     colratios[x] = 0;
@@ -345,7 +344,7 @@ for (i = item_list->next; i != NULL; i = i->next)
 
   set_align(&align_default, &align_char_default, &align_charoff_default, tg);
 
-  for (x = 1; x <= colcount; x++)
+  for (int x = 1; x <= colcount; x++)
     {
     td->coldata[x].align = align_default;
     td->coldata[x].charval = align_char_default;
@@ -466,7 +465,7 @@ for (i = item_list->next; i != NULL; i = i->next)
   all of the columns. */
 
   have_ratios = FALSE;
-  for (x = 1; x <= colcount; x++)
+  for (int x = 1; x <= colcount; x++)
     {
     if (!colset[x])
       {
@@ -483,12 +482,12 @@ for (i = item_list->next; i != NULL; i = i->next)
     {
     int ratio_total = 0;
     int available_width = linewidth;
-    for (x = 1; x <= colcount; x++)
+    for (int x = 1; x <= colcount; x++)
       {
       available_width -= colwidths[x];
       ratio_total += colratios[x];
       }
-    for (x = 1; x <= colcount; x++)
+    for (int x = 1; x <= colcount; x++)
       colwidths[x] += MULDIV(available_width, colratios[x], ratio_total);
     }
 
@@ -497,7 +496,7 @@ for (i = item_list->next; i != NULL; i = i->next)
   DEBUG(D_itable) debug_printf("Table with %d columns\nWidths:\n", colcount);
 
   width_total = 0;
-  for (x = 1; x <= colcount; x++)
+  for (int x = 1; x <= colcount; x++)
     {
     DEBUG(D_itable) debug_printf(" %s", misc_formatfixed(colwidths[x]));
     width_total += colwidths[x];
@@ -523,7 +522,7 @@ for (i = item_list->next; i != NULL; i = i->next)
   /* Now reduce the width of each column by the left and right cell
   indentations. */
 
-  for (x = 1; x <= colcount; x++)
+  for (int x = 1; x <= colcount; x++)
     {
     if (x != 1 || (td->flags & TDF_SIDEFRAME) != 0)
       colwidths[x] -= table_left_col_space;
@@ -537,7 +536,7 @@ for (i = item_list->next; i != NULL; i = i->next)
   td->twidth = width_total;
   td->indent = table_overall_indent;
   td->colcount = colcount;
-  for (x = 1; x <= colcount; x++) td->coldata[x].width = colwidths[x];
+  for (int x = 1; x <= colcount; x++) td->coldata[x].width = colwidths[x];
 
   tdi = misc_malloc(sizeof(item));
   tdi->partner = tdi;
