@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020  */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains code for creating a table of contents. */
 
@@ -28,6 +29,7 @@ static BOOL in_section;
 static BOOL index_headings_pdf_toc;
 
 
+
 /*************************************************
 *          Save raw titles for TOC               *
 *************************************************/
@@ -46,11 +48,7 @@ Returns:       TRUE to continue processing; FALSE to stop
 BOOL
 toc_save_raw_titles(item *item_list)
 {
-int k;
-item *i, *new;
-lengthstring *ls;
-
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
   if (!ISSECT(i->name) &&
       Ustrcmp(i->name, "chapter")  != 0 &&
@@ -64,9 +62,10 @@ for (i = item_list; i != NULL; i = i->next)
   the main item, that means the raw elements will end up in the opposite order.
   If there is no title, put in a default. */
 
-  for (k = 0; titels[k] != NULL; k++)
+  for (int k = 0; titels[k] != NULL; k++)
     {
-    ls = misc_find_title(i, titels[k]);
+    item *new;
+    lengthstring *ls = misc_find_title(i, titels[k]);
     if (ls == NULL)
       {
       if (titels[k+1] != NULL) continue;  /* Ignore unless title */
@@ -111,7 +110,6 @@ return TRUE;
 
 
 
-
 /*************************************************
 *          Handle item for TOC                   *
 *************************************************/
@@ -330,7 +328,6 @@ toc_make(item *body_item_list, item *pref_item_list)
 {
 BOOL rc;
 int nest_stackptr = 0;
-item *i;
 item *nest_stack[NESTSTACKSIZE];
 uschar tfilename[128];
 
@@ -372,7 +369,7 @@ if (pref_item_list != NULL)
   memcpy(toc_printed_sections, toc_sections_preface_default,
     sizeof(toc_sections_preface_default));
   number_sections[0] = FALSE;
-  for (i = pref_item_list; i != NULL; i = i->next)
+  for (item *i = pref_item_list; i != NULL; i = i->next)
     toc_handle_item(i, nest_stack, &nest_stackptr, TRUE);
   }
 
@@ -386,7 +383,7 @@ memcpy(number_sections, number_sections_default,
   sizeof(number_sections_default));
 toc_page = 0;
 
-for (i = body_item_list; i != NULL; i = i->next)
+for (item *i = body_item_list; i != NULL; i = i->next)
   toc_handle_item(i, nest_stack, &nest_stackptr, FALSE);
 
 /* If it turns out that we have not actually generated any TOC data, abandon
@@ -448,7 +445,7 @@ the indent appropriately. */
 
 if (rc && pref_item_list != NULL)
   {
-  for (i = toc_item_list; i != NULL; i = i->next)
+  for (item *i = toc_item_list; i != NULL; i = i->next)
     {
     outputline *ol;
 
