@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: March 2023 */
 
 /* This module contains code for doing things to URLs. */
 
@@ -25,10 +26,9 @@ Returns:   TRUE
 BOOL
 url_check(item *item_list)
 {
-item *i, *ii;
-
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
+  item *ii;
   int ulen;
   paramstr *p;
   textblock *t;
