@@ -2,10 +2,10 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2020 */
-/* Last modified: August 2020 */
+/* Copyright (c) Philip Hazel, 2023 */
+/* Created in 2006; last modified: April 2023 */
 
-/* This module contains code for writing the final output file. */
+/* This module contains code for writing the final PostScript output. */
 
 
 #include "sdop.h"
@@ -24,9 +24,9 @@ static BOOL  all_pages;      /* TRUE if there's no page selection */
 static int   ccount;         /* Count of PostScript chars in an output line */
 static FILE *outfile;        /* The output file */
 static int   listcount;      /* For numbering/bulleting lists */
-static int   listnumeration;
+static int   listnumeration; /* Type of numeration for ordered list */
 static int   liststackptr = 0;
-static int   liststack[MAXLISTNEST];
+static int   liststack[2*MAXLISTNEST];
 static int   page_count;     /* The physical page count */
 static int   setcolour;
 static int   setfont;        /* The currently set font */
@@ -85,10 +85,10 @@ static int hfent_list_count = sizeof(hfent_list)/sizeof(hfent);
 
 
 /*************************************************
-*          Checked print function                *
+*          Checked write function                *
 *************************************************/
 
-/* Prints to outfile if output is not suppressed.
+/* Writes to outfile if output is not suppressed.
 
 Arguments:
   format       the format
@@ -98,7 +98,7 @@ Returns:       number of characters output
 */
 
 static int
-cprintf(const char *format, ...)
+cwritef(const char *format, ...)
 {
 int yield;
 va_list ap;
@@ -127,11 +127,10 @@ Returns:          TRUE if page is to be output
 static BOOL
 okpage(unsigned int pagenumber, BOOL isfm)
 {
-pagelist *pl;
 BOOL odd = (pagenumber & 1) == 1;
 if ((odd && !pages_odd) || (!odd && !pages_even)) return FALSE;
 if (pages_front == NULL && pages_main == NULL) return TRUE;
-for (pl = isfm? pages_front : pages_main; pl != NULL; pl = pl->next)
+for (pagelist *pl = isfm? pages_front : pages_main; pl != NULL; pl = pl->next)
   if (pagenumber >= pl->start && pagenumber <= pl->end) return TRUE;
 return FALSE;
 }
@@ -153,17 +152,18 @@ pcheck(void)
 {
 if (ccount > PLINETHRESH)
   {
-  (void)cprintf("\n");
+  (void)cwritef("\n");
   ccount = 0;
   }
 else if (ccount > 0)
   {
-  (void)cprintf(" ");
+  (void)cwritef(" ");
   ccount++;
   }
 }
 
 
+
 /*************************************************
 *         Ensure a colour is current             *
 *************************************************/
@@ -185,7 +185,6 @@ setcolour = c;
 
 
 
-
 /*************************************************
 *         Ensure a font is current               *
 *************************************************/
@@ -305,9 +304,9 @@ else
 fn = vf->pnumber + fr;
 if (setfont != fn)
   {
-  ccount += cprintf("%s", pre);
+  ccount += cwritef("%s", pre);
   pcheck();
-  ccount += cprintf("%d Sf", fn);
+  ccount += cwritef("%d Sf", fn);
   pcheck();
   *chfont = TRUE;
   setfont = fn;
@@ -333,7 +332,7 @@ set_linewidth(int linewidth)
 if (setlinewidth != linewidth)
   {
   pcheck();
-  ccount += cprintf("%s Slw", misc_formatfixed(linewidth));
+  ccount += cwritef("%s Slw", misc_formatfixed(linewidth));
   setlinewidth = linewidth;
   }
 }
@@ -365,20 +364,21 @@ va_start(ap, n);
 set_linewidth(thickness);
 check_colour(0);
 pcheck();
-ccount += cprintf("%s ", misc_formatfixed(x0));
-ccount += cprintf("%s Mt", misc_formatfixed(y0));
+ccount += cwritef("%s ", misc_formatfixed(x0));
+ccount += cwritef("%s Mt", misc_formatfixed(y0));
 
 while (n-- > 0)
   {
   pcheck();
-  ccount += cprintf("%s ", misc_formatfixed(va_arg(ap, int)));
-  ccount += cprintf("%s RLt", misc_formatfixed(va_arg(ap, int)));
+  ccount += cwritef("%s ", misc_formatfixed(va_arg(ap, int)));
+  ccount += cwritef("%s RLt", misc_formatfixed(va_arg(ap, int)));
   }
 
-ccount += cprintf(" St");
+ccount += cwritef(" St");
 }
 
 
+
 /*************************************************
 *             Output a change bar                *
 *************************************************/
@@ -419,21 +419,21 @@ init_page(uschar *pageid)
 {
 if (!suppress) ++page_count;    /* Number of actual pages written */
 
-(void)cprintf("%%%%Page: %s %d\n", pageid, page_count);
-(void)cprintf("%%%%BeginPageSetup\n");
-(void)cprintf("/pagesave save def\n");
-(void)cprintf("%%%%EndPageSetup\n");
+(void)cwritef("%%%%Page: %s %d\n", pageid, page_count);
+(void)cwritef("%%%%BeginPageSetup\n");
+(void)cwritef("/pagesave save def\n");
+(void)cwritef("%%%%EndPageSetup\n");
 
 if (paper_size != NULL &&
     (background_colour[0] != 0 ||
      background_colour[1] != 0 ||
      background_colour[2] != 0))
   {
-  (void)cprintf("0 0 Mt %g 0 RLt 0 %g RLt -%g 0 RLt closepath currentrgbcolor\n",
+  (void)cwritef("0 0 Mt %g 0 RLt 0 %g RLt -%g 0 RLt closepath currentrgbcolor\n",
      paper_size_width, paper_size_height, paper_size_width);
-  (void)cprintf("%s ", misc_formatfixed(background_colour[0]));
-  (void)cprintf("%s ", misc_formatfixed(background_colour[1]));
-  (void)cprintf("%s setrgbcolor fill setrgbcolor\n",
+  (void)cwritef("%s ", misc_formatfixed(background_colour[0]));
+  (void)cwritef("%s ", misc_formatfixed(background_colour[1]));
+  (void)cwritef("%s setrgbcolor fill setrgbcolor\n",
     misc_formatfixed(background_colour[2]));
   }
 
@@ -750,8 +750,8 @@ for (i = pagestart->next;
       {
       if (Ustrcmp(j->name, "imageobject") == 0)
         {
-        int depth = suppress? 0 : object_write_image(j, ypos, outfile,
-          &object_width, &object_justify);
+        int depth = object_write_image(j, ypos, outfile, &object_width,
+          &object_justify);
         if (depth >= 0)
           {
           ypos -= depth;
@@ -1034,6 +1034,7 @@ for (i = pagestart->next;
   if (Ustrcmp(name, "itemizedlist") == 0)
     {
     liststack[liststackptr++] = listcount;
+    liststack[liststackptr++] = 0;         /* Not relevant for itemized list */
     listcount = -font_get_bullet(i);
     if (listcount == 0)
       {
@@ -1066,6 +1067,8 @@ for (i = pagestart->next;
   if (Ustrcmp(name, "orderedlist") == 0)
     {
     paramstr *p = misc_param_find(i, US"numeration");
+    liststack[liststackptr++] = listcount;
+    liststack[liststackptr++] = listnumeration;
     listnumeration = list_numeration_default;
     if (p != NULL)
       {
@@ -1076,8 +1079,7 @@ for (i = pagestart->next;
       else if (Ustrcmp(p->value, "upperroman") == 0) listnumeration = LN_ROMAN;
       else error(67, p->value);
       }
-    liststack[liststackptr++] = listcount;
-    listcount = +1;
+    listcount = 1;  /* Number of first item */
     continue;
     }
 
@@ -1086,6 +1088,7 @@ for (i = pagestart->next;
   if (Ustrcmp(name, "variablelist") == 0)
     {
     liststack[liststackptr++] = listcount;
+    liststack[liststackptr++] = 0;    /* Not relevant for variable list */
     listcount = -BULLET_NONE;
     continue;
     }
@@ -1097,6 +1100,7 @@ for (i = pagestart->next;
         Ustrcmp(i->partner->name, "orderedlist") == 0 ||
         Ustrcmp(i->partner->name, "variablelist") == 0))
     {
+    listnumeration = liststack[--liststackptr];
     listcount = liststack[--liststackptr];
     continue;
     }
@@ -1249,7 +1253,7 @@ for (i = pagestart->next;
 
     if (ccount > 0)
       {
-      (void)cprintf("\n");
+      (void)cwritef("\n");
       ccount = 0;
       }
 
@@ -1264,7 +1268,7 @@ for (i = pagestart->next;
       {
       uschar buff[64];
       (void)error(26, page_count);
-      (void)cprintf("\npagesave restore showpage\n"
+      (void)cwritef("\npagesave restore showpage\n"
                     "%%%%PageTrailer\n\n");
       (void)sprintf(CS buff, "XX-%d", ++overflow_page_count);
       init_page(buff);
@@ -1308,8 +1312,8 @@ for (i = pagestart->next;
                  (olist_tag_colour[2]);
         }
 
-      ccount += cprintf("%s ", misc_formatfixed(indent - back));
-      ccount += cprintf("%s Mt ", misc_formatfixed(ypos));
+      ccount += cwritef("%s ", misc_formatfixed(indent - back));
+      ccount += cwritef("%s Mt ", misc_formatfixed(ypos));
 
       /* Find the vfont that corresponds to the current parameters of the
       list's vfont (which may change during the input). Note that the size is
@@ -1333,7 +1337,7 @@ for (i = pagestart->next;
         {
         int code = set_font(olvfont, -listcount, US"", &chfont,
           &inaux);
-        ccount += cprintf(
+        ccount += cwritef(
           (code == '(' || code == ')' || code == '\\')? "(\\%c) show " :
           (code >= 32  && code <= 126)? "(%c) show " : "(\\%03o) show ",
           code);
@@ -1374,7 +1378,7 @@ for (i = pagestart->next;
           break;
           }
 
-        ccount += cprintf("(");
+        ccount += cwritef("(");
         (void)sprintf(CS outbuffer, CS olist_format, buffer);
 
         /* Now output the numeration. */
@@ -1385,18 +1389,18 @@ for (i = pagestart->next;
           GETCHARINC(c, s);
           code = set_font(olvfont, c, US")S", &chfont, &inaux);
           if (chfont)
-            ccount += cprintf("(");
+            ccount += cwritef("(");
           else if (ccount > PLINETHRESH + 1)
             {
-            (void)cprintf(")S\n(");
+            (void)cwritef(")S\n(");
             ccount = 1;
             }
-          ccount += cprintf(
+          ccount += cwritef(
             (code == '(' || code == ')' || code == '\\')? "\\%c" :
             (code >= 32  && code <= 126)? "%c" : "\\%03o",
             code);
           }
-        ccount += cprintf(")show ");
+        ccount += cwritef(")show ");
         }
 
       marklistitem = FALSE;
@@ -1415,15 +1419,15 @@ for (i = pagestart->next;
         {
         check_colour(0);     /* Ensure black */
         (void)set_font(tb->vfont, '0', US"", &chfont, &inaux);
-        ccount += cprintf("%s ", misc_formatfixed(margin_left));
-        ccount += cprintf("%s Mt (%d)S ",
+        ccount += cwritef("%s ", misc_formatfixed(margin_left));
+        ccount += cwritef("%s Mt (%d)S ",
           misc_formatfixed(ypos + ol->depth/3), ++nextfn);
         tb =  tb->next;
         }
       if (tb != NULL && (tb->string[0] != 0 || tb->next != NULL))
         {
-        ccount += cprintf("%s ", misc_formatfixed(indent));
-        ccount += cprintf("%s Mt", misc_formatfixed(ypos));
+        ccount += cwritef("%s ", misc_formatfixed(indent));
+        ccount += cwritef("%s Mt", misc_formatfixed(ypos));
         }
       }
 
@@ -1508,9 +1512,9 @@ for (i = pagestart->next;
 
       if (ypos_adjust != 0)
         {
-        if (instring) ccount += cprintf(")S");
+        if (instring) ccount += cwritef(")S");
         instring = FALSE;
-        ccount += cprintf(" 0 %s RMt", misc_formatfixed(ypos_adjust));
+        ccount += cwritef(" 0 %s RMt", misc_formatfixed(ypos_adjust));
         }
 
       /* Unless this feature is disabled, if we are about to output a cross
@@ -1530,10 +1534,10 @@ for (i = pagestart->next;
 
         if (instring)
           {
-          (void)cprintf(")S");
+          (void)cwritef(")S");
           instring = FALSE;
           }
-        (void)cprintf("\n");
+        (void)cwritef("\n");
         ccount = 0;
 
         /* Find the next <xref> in the paragraph. All <xref>s have been checked
@@ -1564,14 +1568,14 @@ for (i = pagestart->next;
         /* Output the appropriate pdfmark stuff for a clickable link, making
         the hot spot just a bit wider and deeper than the character string. */
 
-        (void)cprintf("[/Rect [");
-        (void)cprintf("%s ", misc_formatfixed(xpos - 1000));
-        (void)cprintf("%s ", misc_formatfixed(ypos - 3000));
-        (void)cprintf("%s ", misc_formatfixed(xpos + 1000 +
+        (void)cwritef("[/Rect [");
+        (void)cwritef("%s ", misc_formatfixed(xpos - 1000));
+        (void)cwritef("%s ", misc_formatfixed(ypos - 3000));
+        (void)cwritef("%s ", misc_formatfixed(xpos + 1000 +
                                font_stringwidth(p, tb->vfont)));
-        (void)cprintf("%s", misc_formatfixed(ypos + tb->vfont->size));
-        (void)cprintf("] /Page %s ", pn->value);
-        (void)cprintf("/View [/XYZ 0 %s null] /LNK pdfmark\n", yp->value);
+        (void)cwritef("%s", misc_formatfixed(ypos + tb->vfont->size));
+        (void)cwritef("] /Page %s ", pn->value);
+        (void)cwritef("/View [/XYZ 0 %s null] /LNK pdfmark\n", yp->value);
         }
 
       /* We maintain xpos as the xposition so that we can generate hot spots
@@ -1634,11 +1638,11 @@ for (i = pagestart->next;
           int w = font_charwidth(' ', tb->vfont, NULL);
           if (instring)
             {
-            ccount += cprintf(")S");
+            ccount += cwritef(")S");
             instring = FALSE;
             }
           pcheck();
-          ccount += cprintf("%s R", misc_formatfixed(w + stretch));
+          ccount += cwritef("%s R", misc_formatfixed(w + stretch));
           xpos += stretch;
           lastc = -1;
           continue;
@@ -1650,7 +1654,7 @@ for (i = pagestart->next;
         if (!instring)
           {
           code = set_font(tb->vfont, c, US"", &chfont, &inaux);
-          ccount += cprintf("(");
+          ccount += cwritef("(");
           instring = TRUE;
           }
 
@@ -1669,10 +1673,10 @@ for (i = pagestart->next;
             {
             if (!chfont)
               {
-              ccount += cprintf(")S");
+              ccount += cwritef(")S");
               pcheck();
               }
-            ccount += cprintf("%s R(", misc_formatfixed(k));
+            ccount += cwritef("%s R(", misc_formatfixed(k));
             xpos += k;
             }
 
@@ -1681,10 +1685,10 @@ for (i = pagestart->next;
           else
             {
             if (chfont)
-              ccount += cprintf("(");
+              ccount += cwritef("(");
             else if (ccount > PLINETHRESH + 1)
               {
-              cprintf(")S\n(");
+              cwritef(")S\n(");
               ccount = 1;
               }
             }
@@ -1692,7 +1696,7 @@ for (i = pagestart->next;
 
         /* Output the character */
 
-        ccount += cprintf(
+        ccount += cwritef(
           (code == '(' || code == ')' || code == '\\')? "\\%c" :
           (code >= 32  && code <= 126)? "%c" : "\\%03o",
           code);
@@ -1715,10 +1719,10 @@ for (i = pagestart->next;
         if (tb->next == NULL && (ol->flags & OLF_ADD_HYPHEN) != 0)
           {
           (void)set_font(tb->vfont, '-', US")S", &chfont, &inaux);
-          if (chfont) ccount += cprintf("(");
-          ccount += cprintf("-");
+          if (chfont) ccount += cwritef("(");
+          ccount += cwritef("-");
           }
-        ccount += cprintf(")S");
+        ccount += cwritef(")S");
         }
 
       /* Unless this feature is disabled, if we are about to output a page
@@ -1738,7 +1742,7 @@ for (i = pagestart->next;
         pp = p + tb->length;
         if (pp[-1] == ',') pp--;     /* Ends with comma if continued */
 
-        (void)cprintf("\n");
+        (void)cwritef("\n");
         ccount = 0;
 
         for (;;)
@@ -1778,14 +1782,14 @@ for (i = pagestart->next;
           follows the current position from the end position. */
 
           ixpos = xpos - font_stringwidth(pp + 1, tb->vfont);
-          (void)cprintf("[/Rect [");
-          (void)cprintf("%s ", misc_formatfixed(ixpos - 1000));
-          (void)cprintf("%s ", misc_formatfixed(ypos - 3000));
-          (void)cprintf("%s ", misc_formatfixed(ixpos + 1000 + d*dwidth));
-          (void)cprintf("%s", misc_formatfixed(ypos + tb->vfont->size));
-          (void)cprintf("] /Page %d ", n + title_page_count +
+          (void)cwritef("[/Rect [");
+          (void)cwritef("%s ", misc_formatfixed(ixpos - 1000));
+          (void)cwritef("%s ", misc_formatfixed(ypos - 3000));
+          (void)cwritef("%s ", misc_formatfixed(ixpos + 1000 + d*dwidth));
+          (void)cwritef("%s", misc_formatfixed(ypos + tb->vfont->size));
+          (void)cwritef("] /Page %d ", n + title_page_count +
             toc_page_count + preface_page_count);
-          (void)cprintf("/View [/XYZ 0 %s null] /LNK pdfmark\n",
+          (void)cwritef("/View [/XYZ 0 %s null] /LNK pdfmark\n",
             misc_formatfixed(page_full_length + margin_bottom + 40000));
 
           if (ok > 0) pp -= ok; else break;
@@ -1839,11 +1843,11 @@ for (i = pagestart->next;
             }
 
           pcheck();
-          ccount += cprintf("%s R",
+          ccount += cwritef("%s R",
             misc_formatfixed(toc_fill_leftspace + avail));
           (void)set_font(toc_fill_vfont_ptr, toc_fill_string[0], US"", &chfont,
             &inaux);
-          ccount += cprintf("(");
+          ccount += cwritef("(");
 
           while (times-- > 0)
             {
@@ -1854,20 +1858,20 @@ for (i = pagestart->next;
               GETCHARINC(c, s);
               code = set_font(toc_fill_vfont_ptr, c, US")S", &chfont, &inaux);
               if (chfont)
-                ccount += cprintf("(");
+                ccount += cwritef("(");
               else if (ccount > PLINETHRESH + 1)
                 {
-                (void)cprintf(")S\n(");
+                (void)cwritef(")S\n(");
                 ccount = 1;
                 }
-              ccount += cprintf(
+              ccount += cwritef(
                 (code == '(' || code == ')' || code == '\\')? "\\%c" :
                 (code >= 32  && code <= 126)? "%c" : "\\%03o",
                 code);
               }
             }
 
-          ccount += cprintf(")S");
+          ccount += cwritef(")S");
           }
         }
       }      /* End of TOC fill code */
@@ -2060,7 +2064,6 @@ return ntb;
 
 
 
-
 /*************************************************
 *          Write head or foot lines              *
 *************************************************/
@@ -2086,7 +2089,6 @@ static item hfdummy = { NULL, NULL, &hfdummy, 0, 0,
 static void
 write_headfoot(item *item_list, int pagenumber)
 {
-item *i;
 int pcount;
 uschar *save_filename = read_filename;
 textblock *textsave[MAXHEADFOOTPARA];
@@ -2096,7 +2098,7 @@ inheadorfoot = TRUE;               /* Suppresses "any-only" debugging */
 /* Copy and modify the text blocks */
 
 pcount = 0;
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
   paragraph *pp;
   textblock *tb;
@@ -2132,7 +2134,7 @@ write_page(&hfdummy, pagenumber, FALSE);
 /* Free copied text blocks and formatted data, and restore the originals */
 
 pcount = 0;
-for (i = item_list; i != NULL; i = i->next)
+for (item *i = item_list; i != NULL; i = i->next)
   {
   paragraph *pp;
   outputline *ol, *nol;
@@ -2221,7 +2223,6 @@ int footnote_depth = 0;
 vfontstr ilist_top_vfont, olist_top_vfont;
 int ilist_top_colour[3], olist_top_colour[3];
 item *nexti;
-item *ii;
 
 DEBUG(D_any) running_page(US"", pagetext);
 
@@ -2245,7 +2246,7 @@ memcpy(olist_top_colour, olist_tag_colour, 3*sizeof(int));
 (3) the presence and depth of footnotes.
 */
 
-for (ii = i->next;
+for (item *ii = i->next;
      ii != NULL && Ustrcmp(ii->name, "#PDATA") != 0;
      ii = ii->next)
   {
@@ -2382,12 +2383,12 @@ if (page_foot_length > 0 && (i->flags & IF_NOHEADFOOT) == 0)
   write_headfoot(filist, pagenumber);
   }
 
-(void)cprintf("\npagesave restore showpage\n%%%%PageTrailer\n\n");
+(void)cwritef("\npagesave restore showpage\n%%%%PageTrailer\n\n");
 
 /* Finally, we must now scan to find the *last* section name in this page, in
 case there is no such name on the next page. */
 
-for (ii = i->next;
+for (item *ii = i->next;
      ii != NULL && Ustrcmp(ii->name, "#PDATA") != 0;
      ii = ii->next)
   {
@@ -2548,22 +2549,22 @@ set_pagedata_defaults();
 time(&timer);
 suppress = FALSE;
 
-(void)cprintf("%%!PS-Adobe-3.0\n");
-(void)cprintf("%%%%Creator: SDoP %s\n", SDOP_VERSION);
-(void)cprintf("%%%%CreationDate: %s", ctime(&timer));
-(void)cprintf("%%%%Pages: (atend)\n");
+(void)cwritef("%%!PS-Adobe-3.0\n");
+(void)cwritef("%%%%Creator: SDoP %s\n", SDOP_VERSION);
+(void)cwritef("%%%%CreationDate: %s", ctime(&timer));
+(void)cwritef("%%%%Pages: (atend)\n");
 
-(void)cprintf("%%%%DocumentNeededResources:\n");
+(void)cwritef("%%%%DocumentNeededResources:\n");
 for (af = afont_list; af != NULL; af = af->next)
   {
   afontstr *bf;
   for (bf = afont_list; bf != af; bf = bf->next)
     { if (Ustrcmp(af->name, bf->name) == 0) break; }
-  if (af == bf) (void)cprintf("%%%%+ font %s\n", af->name);
+  if (af == bf) (void)cwritef("%%%%+ font %s\n", af->name);
   }
 
-(void)cprintf("%%%%Requirements: numcopies(1)\n");
-(void)cprintf("%%%%EndComments\n\n");
+(void)cwritef("%%%%Requirements: numcopies(1)\n");
+(void)cwritef("%%%%EndComments\n\n");
 
 /* Copy the PostScript header file, omitting any single-% comments and
 any blank lines. */
@@ -2576,26 +2577,26 @@ if (ph == NULL)  /* Hard */
 while (Ufgets(buffer, sizeof(buffer), ph) != NULL)
   {
   if (buffer[0] == '\n' || (buffer[0] == '%' && buffer[1] != '%')) continue;
-  (void)cprintf("%s", CS buffer);
+  (void)cwritef("%s", CS buffer);
   }
 (void)fclose(ph);
 
 /* Do the font binding in the general setup section. */
 
-(void)cprintf("\n%%%%BeginSetup\n");
+(void)cwritef("\n%%%%BeginSetup\n");
 
 /* Use this to prevent compression if you want to look at a PDF generated from
 this PostScript. */
 
 #if 0
-(void)cprintf("systemdict /setdistillerparams known {\n"
+(void)cwritef("systemdict /setdistillerparams known {\n"
   "<< /CompressPages false >> setdistillerparams\n} if\n");
 #endif
 
 /* Handle paper size, if set */
 
 if (paper_size != NULL)
-  (void)cprintf("<< /PageSize [ %g %g ] >> setpagedevice\n", paper_size_width,
+  (void)cwritef("<< /PageSize [ %g %g ] >> setpagedevice\n", paper_size_width,
     paper_size_height);
 
 /* Let a PDF know how the pages are labelled: the front matter, Contents and
@@ -2604,7 +2605,7 @@ output has only certain pages selected, because it doesn't then work. */
 
 if (all_pages)
   {
-  (void)cprintf("[ {Catalog} << /PageLabels << /Nums [\n"
+  (void)cwritef("[ {Catalog} << /PageLabels << /Nums [\n"
     "0 << /S /r >> "
     "%d << /S /D >> "
     "] >> >> /PUT pdfmark\n",
@@ -2612,7 +2613,7 @@ if (all_pages)
 
   /* Set up the default viewing state, show the bookmarks (outlines). */
 
-  (void)cprintf(
+  (void)cwritef(
     "[/View [/XYZ null null 1] /Page 1 /PageMode /UseOutlines "
     "/DOCVIEW pdfmark\n");
 
@@ -2620,11 +2621,11 @@ if (all_pages)
   that page numbers start from 1. */
 
   if (title_page_count != 0)
-    (void)cprintf(
+    (void)cwritef(
       "[/Title (Title page) /Page 1 /View [/XYZ null null 1] /OUT pdfmark\n");
 
   if (toc_item_list->next != NULL)
-    (void)cprintf(
+    (void)cwritef(
       "[/Title (Contents) /Page %d /View [/XYZ null null 1] /OUT pdfmark\n",
       title_page_count + 1);
 
@@ -2641,13 +2642,13 @@ if (all_pages)
     for (pt = pdf->next; pt != NULL && pt->level != pdf->level; pt = pt->next)
       { if (pt->level == pdf->level + 1) count++; }
 
-    (void)cprintf("[/Title (");
+    (void)cwritef("[/Title (");
 
     while (*t != 0)
       {
       int code;
       GETCHARINC(code, t);
-      (void)cprintf(
+      (void)cwritef(
         (code == HARD_SPACE)?    " " :
         (code == SOFT_HYPHEN)?   ""  :
         (code == ZERO_SPACE)?    ""  :
@@ -2665,11 +2666,11 @@ if (all_pages)
         (code == '(' || code == ')' || code == '\\')? "\\%c" :
         (code >= 32  && code <= 126)? "%c" : "\\%03o", code);
       }
-    (void)cprintf(") /Page %d /View [/XYZ null null 1] ",
+    (void)cwritef(") /Page %d /View [/XYZ null null 1] ",
       title_page_count + toc_page_count + pdf->page +
         (pdf->ispreface? -PREFACE_DUMMY_PAGE : preface_page_count));
-    if (count > 0) (void)cprintf("/Count %d ", -count);
-    (void)cprintf("/OUT pdfmark\n");
+    if (count > 0) (void)cwritef("/Count %d ", -count);
+    (void)cwritef("/OUT pdfmark\n");
     }
   }
 
@@ -2678,8 +2679,8 @@ if (all_pages)
 afontnumber = 0;
 for (af = afont_list; af != NULL; af = af->next)
   {
-  (void)cprintf("%%%%IncludeResource: font %s\n", af->name);
-  (void)cprintf("/af%d /af%d /%s inf\n", afontnumber, afontnumber+1,
+  (void)cwritef("%%%%IncludeResource: font %s\n", af->name);
+  (void)cwritef("/af%d /af%d /%s inf\n", afontnumber, afontnumber+1,
     af->name);
   af->psnumber = afontnumber;
   afontnumber += 2;
@@ -2692,19 +2693,19 @@ to allow for more than 256 characters. */
 vfontcount = 0;
 for (vf = vfont_list; vf != NULL; vf = vf->next) vfontcount++;
 
-(void)cprintf("/vf %d array def\n", vfontcount * 2);
+(void)cwritef("/vf %d array def\n", vfontcount * 2);
 
 vfontcount = 0;
 for (vf = vfont_list; vf != NULL; vf = vf->next)
   {
   vf->pnumber = vfontcount;
-  (void)cprintf("vf %d af%d %s scalefont put\n", vfontcount++,
+  (void)cwritef("vf %d af%d %s scalefont put\n", vfontcount++,
     vf->afont->psnumber, misc_formatfixed(vf->size));
-  (void)cprintf("vf %d af%d %s scalefont put\n", vfontcount++,
+  (void)cwritef("vf %d af%d %s scalefont put\n", vfontcount++,
     vf->afont->psnumber + 1, misc_formatfixed(vf->size));
   }
 
-(void)cprintf("%%%%EndSetup\n\n");
+(void)cwritef("%%%%EndSetup\n\n");
 
 /* Now output the selected pages. */
 
@@ -2727,7 +2728,7 @@ while (i != NULL && i->next != NULL)
   ypos = ytoppage = page_full_length + margin_bottom;
   margin_left = ((pagenumber & 1) == 0)? margin_left_recto : margin_left_verso;
   i = write_page(i, pagenumber, FALSE);
-  (void)cprintf("\npagesave restore showpage\n%%%%PageTrailer\n\n");
+  (void)cwritef("\npagesave restore showpage\n%%%%PageTrailer\n\n");
   }
 
 
@@ -2789,7 +2790,7 @@ while (i != NULL && i->next != NULL)
     write_headfoot(toc_foot_item_list, pagenumber);
     }
 
-  (void)cprintf("\npagesave restore showpage\n%%%%PageTrailer\n\n");
+  (void)cwritef("\npagesave restore showpage\n%%%%PageTrailer\n\n");
 
   /* Move on to next page */
 
@@ -2832,6 +2833,7 @@ chaptitblock = secttitblock = NULL;
 i = main_item_list->next;       /* The first #PDATA (page data) item */
 
 DEBUG(D_any) if (i != NULL) debug_printf("Writing main body etc.\n");
+svg_listignored = FALSE;        /* Will have already been shown */
 
 while (i != NULL && i->next != NULL)
   {
@@ -2846,7 +2848,7 @@ while (i != NULL && i->next != NULL)
 /* Write terminating stuff and close the file. */
 
 suppress = FALSE;
-(void)cprintf("%%%%Trailer\n%%%%Pages: %d\n", page_count);
+(void)cwritef("%%%%Trailer\n%%%%Pages: %d\n", page_count);
 (void)fclose(outfile);
 
 DEBUG(D_any) debug_printf("Finished writing\n");
